# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/satellite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import satellite_pb2 as admin_dot_v1_dot_types_dot_v1_dot_satellite__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/satellite.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/satellite.proto\",\n\x16\x43reateSatelliteRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\")\n\x17\x43reateSatelliteResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetSatelliteByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x18GetSatelliteByIdResponse\x12:\n\tsatellite\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\tsatellite\"\x16\n\x14GetSatellitesRequest\"U\n\x15GetSatellitesResponse\x12<\n\nsatellites\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\nsatellites\"(\n\x16\x44\x65leteSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteSatelliteResponse2\xef\x02\n\x10SatelliteService\x12V\n\x0f\x43reateSatellite\x12 .admin.v1.CreateSatelliteRequest\x1a!.admin.v1.CreateSatelliteResponse\x12Y\n\x10GetSatelliteById\x12!.admin.v1.GetSatelliteByIdRequest\x1a\".admin.v1.GetSatelliteByIdResponse\x12P\n\rGetSatellites\x12\x1e.admin.v1.GetSatellitesRequest\x1a\x1f.admin.v1.GetSatellitesResponse\x12V\n\x0f\x44\x65leteSatellite\x12 .admin.v1.DeleteSatelliteRequest\x1a!.admin.v1.DeleteSatelliteResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x0eSatelliteProtoP\x01ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.satellite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\016SatelliteProtoP\001ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESATELLITEREQUEST']._serialized_start=73
  _globals['_CREATESATELLITEREQUEST']._serialized_end=117
  _globals['_CREATESATELLITERESPONSE']._serialized_start=119
  _globals['_CREATESATELLITERESPONSE']._serialized_end=160
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_start=162
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_end=203
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_start=205
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_end=291
  _globals['_GETSATELLITESREQUEST']._serialized_start=293
  _globals['_GETSATELLITESREQUEST']._serialized_end=315
  _globals['_GETSATELLITESRESPONSE']._serialized_start=317
  _globals['_GETSATELLITESRESPONSE']._serialized_end=402
  _globals['_DELETESATELLITEREQUEST']._serialized_start=404
  _globals['_DELETESATELLITEREQUEST']._serialized_end=444
  _globals['_DELETESATELLITERESPONSE']._serialized_start=446
  _globals['_DELETESATELLITERESPONSE']._serialized_end=471
  _globals['_SATELLITESERVICE']._serialized_start=474
  _globals['_SATELLITESERVICE']._serialized_end=841
# @@protoc_insertion_point(module_scope)
