# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/policies.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import policy_pb2 as admin_dot_v1_dot_types_dot_v1_dot_policy__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61\x64min/v1/policies.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/policy.proto\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1avalidate/v1/validate.proto\"g\n\x1d\x43reatePolicySuggestionRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\"@\n\x1e\x43reatePolicySuggestionResponse\x12\x1e\n\nsuggestion\x18\x01 \x01(\tR\nsuggestion\".\n\x13\x44\x65letePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65letePolicyResponse\"<\n\x1d\x45valuatePolicyValidityRequest\x12\x1b\n\x04\x63ode\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\"^\n\x1e\x45valuatePolicyValidityResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x10\n\x03\x61st\x18\x02 \x01(\tR\x03\x61st\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\"\xb6\x02\n\x13\x43reatePolicyRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\x12\x46\n\x0cnotification\x18\x04 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x05 \x03(\tR\x06owners\x12\x42\n\x0bsource_type\x18\x06 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\"I\n\x14\x43reatePolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"\xc6\x02\n\x13UpdatePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x42\n\x0bsource_type\x18\x02 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x1b\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x05 \x01(\tR\x04\x63ode\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\"\x16\n\x14UpdatePolicyResponse\"/\n\x10GetPolicyRequest\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\"F\n\x11GetPolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"n\n\x12GetPoliciesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\x92\x01\n\x13GetPoliciesResponse\x12\x35\n\x08policies\x18\x01 \x03(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x08policies\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata2\xf6\x04\n\rPolicyService\x12L\n\x0bGetPolicies\x12\x1c.admin.v1.GetPoliciesRequest\x1a\x1d.admin.v1.GetPoliciesResponse\"\x00\x12\x46\n\tGetPolicy\x12\x1a.admin.v1.GetPolicyRequest\x1a\x1b.admin.v1.GetPolicyResponse\"\x00\x12O\n\x0c\x43reatePolicy\x12\x1d.admin.v1.CreatePolicyRequest\x1a\x1e.admin.v1.CreatePolicyResponse\"\x00\x12O\n\x0cUpdatePolicy\x12\x1d.admin.v1.UpdatePolicyRequest\x1a\x1e.admin.v1.UpdatePolicyResponse\"\x00\x12O\n\x0c\x44\x65letePolicy\x12\x1d.admin.v1.DeletePolicyRequest\x1a\x1e.admin.v1.DeletePolicyResponse\"\x00\x12m\n\x16\x45valuatePolicyValidity\x12\'.admin.v1.EvaluatePolicyValidityRequest\x1a(.admin.v1.EvaluatePolicyValidityResponse\"\x00\x12m\n\x16\x43reatePolicySuggestion\x12\'.admin.v1.CreatePolicySuggestionRequest\x1a(.admin.v1.CreatePolicySuggestionResponse\"\x00\x42\xa8\x01\n\x0c\x63om.admin.v1B\rPoliciesProtoP\x01ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.policies_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\rPoliciesProtoP\001ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['description']._options = None
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEPOLICYREQUEST.fields_by_name['id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _EVALUATEPOLICYVALIDITYREQUEST.fields_by_name['code']._options = None
  _EVALUATEPOLICYVALIDITYREQUEST.fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['description']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['code']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['notification']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _CREATEPOLICYREQUEST.fields_by_name['source_type']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _UPDATEPOLICYREQUEST.fields_by_name['id']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['source_type']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _UPDATEPOLICYREQUEST.fields_by_name['name']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['description']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['notification']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_start=136
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_end=239
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_start=241
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_end=305
  _globals['_DELETEPOLICYREQUEST']._serialized_start=307
  _globals['_DELETEPOLICYREQUEST']._serialized_end=353
  _globals['_DELETEPOLICYRESPONSE']._serialized_start=355
  _globals['_DELETEPOLICYRESPONSE']._serialized_end=377
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_start=379
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_end=439
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_start=441
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_end=535
  _globals['_CREATEPOLICYREQUEST']._serialized_start=538
  _globals['_CREATEPOLICYREQUEST']._serialized_end=848
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=850
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=923
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=926
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=1252
  _globals['_UPDATEPOLICYRESPONSE']._serialized_start=1254
  _globals['_UPDATEPOLICYRESPONSE']._serialized_end=1276
  _globals['_GETPOLICYREQUEST']._serialized_start=1278
  _globals['_GETPOLICYREQUEST']._serialized_end=1325
  _globals['_GETPOLICYRESPONSE']._serialized_start=1327
  _globals['_GETPOLICYRESPONSE']._serialized_end=1397
  _globals['_GETPOLICIESREQUEST']._serialized_start=1399
  _globals['_GETPOLICIESREQUEST']._serialized_end=1509
  _globals['_GETPOLICIESRESPONSE']._serialized_start=1512
  _globals['_GETPOLICIESRESPONSE']._serialized_end=1658
  _globals['_POLICYSERVICE']._serialized_start=1661
  _globals['_POLICYSERVICE']._serialized_end=2291
# @@protoc_insertion_point(module_scope)
